/**
 * @fileoverview descr
 * @author impudev
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/public-api-imports"),
  RuleTester = require("eslint").RuleTester;


//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester({
  parserOptions: {ecmaVersion: 6, sourceType: 'module'}
});

const aliasOptions = [
  {
    alias: '@'
  }
]

ruleTester.run("public-api-imports", rule, {
  valid: [
    {
      code: "import { addCommentFormActions, addCommentFormReducer } from '../../model/slices/addCommentForm'",
      errors: [],
    },
    {
      code: "import { addCommentFormActions, addCommentFormReducer } from '@entities/Article'",
      errors: [],
      options: aliasOptions
    },
    {
      filename: 'C:\\1Content\\DEV\\projs\\ulbi\\ulbi-advanced-production\\src\\entities\\file-test.ts',
      code: "import { addCommentFormActions, addCommentFormReducer } from '@entities/Article/testing'",
      errors: [],
      options: [{
        alias: '@',
        testFilesPatterns: ['**/*.test.ts', '**/*.test.ts', '**/StoreDecorator.tsx']
      }],
    },
    {
      filename: 'C:\\1Content\\DEV\\projs\\ulbi\\ulbi-advanced-production\\src\\entities\\StoreDecorator.ts',
      code: "import { addCommentFormActions, addCommentFormReducer } from '@entities/Article/testing'",
      errors: [],
      options: [{
        alias: '@',
        testFilesPatterns: ['**/*.test.ts', '**/*.test.ts', '**/StoreDecorator.tsx']
      }],
    }
  ],

  invalid: [
    {
      code: "import { addCommentFormActions, addCommentFormReducer } from '@/entities/Article/model/file.ts'",
      errors: [{ message: "Абсолютный импорт разрешён только из Public API (index.ts)" }],
      options: aliasOptions
    },
    {
      filename: 'C:\\1Content\\DEV\\projs\\ulbi\\ulbi-advanced-production\\src\\entities\\StoreDecorator.tsx',
      code: "import { addCommentFormActions, addCommentFormReducer } from '@/entities/Article/testing/file.tsx'",
      errors: [{message: 'Абсолютный импорт разрешён только из Public API (index.ts)'}],
      options: [{
        alias: '@',
        testFilesPatterns: ['**/*.test.ts', '**/*.test.ts', '**/StoreDecorator.tsx']
      }],
    },
    {
      filename: 'C:\\1Content\\DEV\\projs\\ulbi\\ulbi-advanced-production\\src\\entities\\forbidden.ts',
      code: "import { addCommentFormActions, addCommentFormReducer } from '@/entities/Article/testing'",
      errors: [{message: 'Тестовые данные необходимо импортировать из publicApi/testing.ts'}],
      options: [{
        alias: '@',
        testFilesPatterns: ['**/*.test.ts', '**/*.test.ts', '**/StoreDecorator.tsx']
      }],
    }
  ],
});
